@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Moai;
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 # ABSTRACT: Mojolicious UI components using modern UI libraries
 
 #pod =head1 SYNOPSIS
@@ -391,7 +391,7 @@ Mojolicious::Plugin::Moai - Mojolicious UI components using modern UI libraries
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -758,6 +758,12 @@ L<Test::Mojo::Role::Moai>, L<Mojolicious::Guides::Rendering>
 
 Doug Bell <preaction@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Mohammad S Anwar
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2019 by Doug Bell.
